@@ -12,6 +12,7 @@ import os
 import sys
 import shutil
 import platform
+from libnvme import nvme
 from staslib.version import KernelVersion
 
 try:
@@ -35,17 +36,28 @@ KERNEL_IFACE_MIN_VERSION = KernelVersion('5.14')
 KERNEL_TP8013_MIN_VERSION = KernelVersion('5.16')
 KERNEL_HOSTKEY_MIN_VERSION = KernelVersion('5.20')
 KERNEL_CTRLKEY_MIN_VERSION = KernelVersion('5.20')
+KERNEL_ALL_MIN_VERSION = max(
+    # Minimum version required to have support for all
+    KERNEL_IFACE_MIN_VERSION,
+    KERNEL_TP8013_MIN_VERSION,
+    KERNEL_HOSTKEY_MIN_VERSION,
+    KERNEL_CTRLKEY_MIN_VERSION,
+)
 
 WELL_KNOWN_DISC_NQN = 'nqn.2014-08.org.nvmexpress.discovery'
 
 PROG_NAME = os.path.basename(sys.argv[0])
 
-NVME_HOSTID = '/etc/nvme/hostid'
-NVME_HOSTNQN = '/etc/nvme/hostnqn'
-NVME_HOSTKEY = '/etc/nvme/hostkey'
+NVME_HOSTID = '@ETC@/nvme/hostid'
+NVME_HOSTNQN = '@ETC@/nvme/hostnqn'
+NVME_HOSTKEY = '@ETC@/nvme/hostkey'
 
-SYS_CONF_FILE = '/etc/stas/sys.conf'
-STAFD_CONF_FILE = '/etc/stas/stafd.conf'
-STACD_CONF_FILE = '/etc/stas/stacd.conf'
+SYS_CONF_FILE = '@ETC@/stas/sys.conf'
+STAFD_CONF_FILE = '@ETC@/stas/stafd.conf'
+STACD_CONF_FILE = '@ETC@/stas/stacd.conf'
+
+HAS_NBFT_SUPPORT = hasattr(nvme, 'nbft_get')
+NBFT_SYSFS_PATH = "/sys/firmware/acpi/tables"
+NBFT_SYSFS_FILENAME = "NBFT*"
 
 SYSTEMCTL = shutil.which('systemctl')
